@@ -297,7 +297,7 @@ def create_diagram(input_data, input_args):
     ax2.xaxis_date()
     ax2.plot(log_datetime, cur_voltage_values, linewidth=1, c='red')
 
-    ax2.set_yticks(range(0, 70, 10))
+    ax2.set_yticks(range(0, 80, 10))
     ax2.xaxis.set_major_formatter(date_format)
 
     ax2.tick_params(axis='both', labelsize=7)
@@ -344,3 +344,31 @@ def find_datetime_in_line(line):
     timestamp_pattern = re.compile(r"(\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{6})")
     m = re.search(timestamp_pattern, line)
     return m[0]
+
+def preprocessing_output_directory(output_directory):
+    """预处理输出目录
+
+    Args:
+        output_directory (string): 输出目录
+
+    Returns:
+        string: 输出目录
+    """
+    try:
+        if not os.path.exists(output_directory):
+            os.makedirs(output_directory)
+
+        # file name like: 20210913175500-log.tar.gz
+        # max file number is 10 in the same time
+        # if files larger than 10, then delete the old ones beyond 10
+        # else do nothing
+        files = os.listdir(output_directory)
+        files = sorted(files, reverse=True)
+        if len(files) > 10:
+            for file in files[10:]:
+                os.remove(f"{output_directory}/{file}")
+
+    except Exception as e:
+        print(f"Error: {e}")
+
+    return output_directory
\ No newline at end of file
