@@ -9,8 +9,6 @@ import os
 from datetime import datetime
 from alive_progress import alive_bar
 
-OUTPUT_DIR = "/tmp/log_trans/"
-OUTPUT_FILE = f"{OUTPUT_DIR}log.tar.gz"
 
 
 def init_input_args(sub_parser):
@@ -32,9 +30,14 @@ def init_input_args(sub_parser):
         "--timestamp",
         help="时间点, 例如：2022-09-05 09:53:10。 默认为当前时间",
         default=datetime.now().strftime("%m-%d-%Y %H:%M:%S"),
+        required=True
     )
+
     sub_parser.add_argument(
-        "--output_file", help=f"输出文件的路径, 默认路径：{OUTPUT_FILE}", default=OUTPUT_FILE
+        "--output_directory",
+        help="输出文件的目录, 默认路径：/tmp/log_trans/",
+        default="/tmp/log_trans/",
+        required=False
     )
 
     # DON'T want to allow --feature and --no-feature at the same time
@@ -62,14 +65,7 @@ def pack_log(input_args):
         input_args: shell 传入的参数
     """
 
-    try:
-        if not os.path.exists(OUTPUT_DIR):
-            os.mkdir(OUTPUT_DIR)
-
-        if os.path.exists(input_args.output_file):
-            os.remove(input_args.output_file)
-    except (FileNotFoundError, IsADirectoryError):
-        pass
+    preprocessing_output_directory(input_args.output_directory)
 
     print(f"input_args.recursive: {input_args.recursive}")
     log_files = set(
@@ -85,10 +81,17 @@ def pack_log(input_args):
 
     print(f"totlal {len(log_files)} files, compress start ...")
 
+    # get current datetime like 20210913175500
+    cur_datetime = datetime.now().strftime("%Y%m%d%H%M%S")
+    output_file_name = f"{cur_datetime}.log.tar.gz"
+    # join args.output_directory and OUTPUT_FILE_NAME
+    output_file_path = os.path.join(input_args.output_directory, output_file_name)
+
+
     # if input_args.compress, tar with gzip
     if input_args.compress:
         with alive_bar(len(log_files),  title='pack with compress') as bar:
-            with tarfile.open(input_args.output_file, "w:gz") as tar:
+            with tarfile.open(output_file_path, "w:gz") as tar:
                 for log_file in log_files:
                     try:
                         tar.add(log_file)
@@ -99,7 +102,7 @@ def pack_log(input_args):
     # else, tar without gzip
     else:
         with alive_bar(len(log_files),  title='pack without compress') as bar:
-            with tarfile.open(input_args.output_file, "w") as tar:
+            with tarfile.open(output_file_path, "w") as tar:
                 for log_file in log_files:
                     try:
                         tar.add(log_file)
@@ -108,7 +111,7 @@ def pack_log(input_args):
                         print(f"file {log_file} is not exist")
 
     # terminal process bar for compress with alive-progress
-    print(f"pack complete, total {len(log_files)} files, output file: {input_args.output_file}")
+    print(f"pack complete, total {len(log_files)} files, output file: {output_file_path}")
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(
